[java-identity-provider] branch main updated: Fix javadoc errors.

Scott Cantor cantor.2 at osu.edu
Thu Dec 16 13:04:29 UTC 2021


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=6e3c478ac5fff294347d8e03e744e4e2e58dad6d

The following commit(s) were added to refs/heads/main by this push:
     new 6e3c478ac Fix javadoc errors.
6e3c478ac is described below

commit 6e3c478ac5fff294347d8e03e744e4e2e58dad6d
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Thu Dec 16 08:04:25 2021 -0500

    Fix javadoc errors.
---
 .../idp/authn/impl/PopulateAuthenticationContextTest.java         | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/idp-authn-impl/src/test/java/net/shibboleth/idp/authn/impl/PopulateAuthenticationContextTest.java b/idp-authn-impl/src/test/java/net/shibboleth/idp/authn/impl/PopulateAuthenticationContextTest.java
index d2765e698..ff3ca9512 100644
--- a/idp-authn-impl/src/test/java/net/shibboleth/idp/authn/impl/PopulateAuthenticationContextTest.java
+++ b/idp-authn-impl/src/test/java/net/shibboleth/idp/authn/impl/PopulateAuthenticationContextTest.java
@@ -44,9 +44,9 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
     /**
      * Test available flows == potential flows.
      * 
      * @throws Exception if something goes wrong
      */
-    @Test public void testIdentical() throws Exception {
+    @Test public void testIdentical() throws ComponentInitializationException {
         
         final PopulateAuthenticationContext action = new PopulateAuthenticationContext();
         action.setAvailableFlows(authenticationFlows);
@@ -70,7 +70,7 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
     /**
      * Test available flows != potential flows.
      * 
      * @throws Exception if something goes wrong
      */
     @Test public void testNonIdentical() throws ComponentInitializationException {
         
@@ -103,7 +103,7 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
     /**
      * Test active flow filtering.
      * 
      * @throws Exception if something goes wrong
      */
     @Test public void testFiltered() throws ComponentInitializationException {
         
@@ -44,9 +44,9 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
      * Test available flows == potential flows.
      * 
-     * @throws Exception if something goes wrong
+     * @throws ComponentInitializationException if something goes wrong
      */
@@ -70,7 +70,7 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
      * Test available flows != potential flows.
      * 
-     * @throws Exception if something goes wrong
+     * @throws ComponentInitializationException if something goes wrong
      */
     @Test public void testNonIdentical() throws ComponentInitializationException {
@@ -103,7 +103,7 @@ final public class PopulateAuthenticationContextTest extends BaseAuthenticationC
      * Test active flow filtering.
      * 
-     * @throws Exception if something goes wrong
+     * @throws ComponentInitializationException if something goes wrong
      */
     @Test public void testFiltered() throws ComponentInitializationException {

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list